Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(219)

Unified Diff: ash/shell.cc

Issue 1909873002: Allow taking screen shot of a non child window which has delegate to paint. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/shell.h ('k') | ash/test/test_screenshot_delegate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/shell.cc
diff --git a/ash/shell.cc b/ash/shell.cc
index c558897d77710c8729d79bc50a327d8d85680c8f..5218bbc021aba6217bacaaf7b6c59b015667c35b 100644
--- a/ash/shell.cc
+++ b/ash/shell.cc
@@ -57,7 +57,7 @@
#include "ash/system/toast/toast_manager.h"
#include "ash/system/tray/system_tray_delegate.h"
#include "ash/system/tray/system_tray_notifier.h"
-#include "ash/utility/partial_screenshot_controller.h"
+#include "ash/utility/screenshot_controller.h"
#include "ash/wm/ash_focus_rules.h"
#include "ash/wm/ash_native_cursor_manager.h"
#include "ash/wm/aura/wm_globals_aura.h"
@@ -810,7 +810,7 @@ Shell::~Shell() {
resolution_notification_controller_.reset();
#endif
desktop_background_controller_.reset();
- partial_screenshot_controller_.reset();
+ screenshot_controller_.reset();
mouse_cursor_filter_.reset();
#if defined(OS_CHROMEOS)
@@ -1036,11 +1036,11 @@ void Shell::Init(const ShellInitParams& init_params) {
AddShellObserver(lock_state_controller_.get());
drag_drop_controller_.reset(new DragDropController);
// |partial_screenshot_controller_| needs to be created (and prepended as a
// pre-target handler) at this point, because |mouse_cursor_filter_| needs to
- // process mouse events prior to partial screenshot session.
+ // process mouse events prior to screenshot session.
// See http://crbug.com/459214
- partial_screenshot_controller_.reset(new PartialScreenshotController());
+ screenshot_controller_.reset(new ScreenshotController());
mouse_cursor_filter_.reset(new MouseCursorEventFilter());
PrependPreTargetHandler(mouse_cursor_filter_.get());
« no previous file with comments | « ash/shell.h ('k') | ash/test/test_screenshot_delegate.h » ('j') | no next file with comments »
@@ -1036,11 +1036,11 @@ void Shell::Init(const ShellInitParams& init_params) {
AddShellObserver(lock_state_controller_.get());
drag_drop_controller_.reset(new DragDropController);
- // |partial_screenshot_controller_| needs to be created (and prepended as a
+ // |screenshot_controller_| needs to be created (and prepended as a
// pre-target handler) at this point, because |mouse_cursor_filter_| needs to

Powered by Google App Engine
This is Rietveld 408576698